==> java-sdk-4.15.7-sources.jar: com/baidu/aip/ocr/OcrConsts.java <==
/*
 * Copyright 2017 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidu.aip.ocr;

public class OcrConsts {

    static final String GENERAL_BASIC = "https://aip.baidubce.com/rest/2.0/ocr/v1/general_basic";

    static final String ACCURATE_BASIC = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate_basic";

    static final String GENERAL = "https://aip.baidubce.com/rest/2.0/ocr/v1/general";

    static final String ACCURATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate";

    static final String GENERAL_ENHANCED = "https://aip.baidubce.com/rest/2.0/ocr/v1/general_enhanced";

    static final String WEB_IMAGE = "https://aip.baidubce.com/rest/2.0/ocr/v1/webimage";

    static final String IDCARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/idcard";

    static final String BANKCARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/bankcard";

    static final String DRIVING_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/driving_license";

    static final String VEHICLE_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vehicle_license";

    static final String LICENSE_PLATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/license_plate";

    static final String BUSINESS_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/business_license";

    static final String RECEIPT = "https://aip.baidubce.com/rest/2.0/ocr/v1/receipt";

    static final String TRAIN_TICKET = "https://aip.baidubce.com/rest/2.0/ocr/v1/train_ticket";

    static final String TAXI_RECEIPT = "https://aip.baidubce.com/rest/2.0/ocr/v1/taxi_receipt";

    static final String FORM = "https://aip.baidubce.com/rest/2.0/ocr/v1/form";

    static final String TABLE_RECOGNIZE = "https://aip.baidubce.com/rest/2.0/solution/v1/form_ocr/request";

    static final String TABLE_RESULT_GET = "https://aip.baidubce.com/rest/2.0/solution/v1/form_ocr/get_request_result";

    static final String VIN_CODE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vin_code";

    static final String QUOTA_INVOICE = "https://aip.baidubce.com/rest/2.0/ocr/v1/quota_invoice";

    static final String HOUSEHOLD_REGISTER = "https://aip.baidubce.com/rest/2.0/ocr/v1/household_register";

    static final String HK_MACAU_EXITENTRYPERMIT = "https://aip.baidubce.com/rest/2.0/ocr/v1/HK_Macau_exitentrypermit";

    static final String TAIWAN_EXITENTRYPERMIT = "https://aip.baidubce.com/rest/2.0/ocr/v1/taiwan_exitentrypermit";

    static final String BIRTH_CERTIFICATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/birth_certificate";

    static final String VEHICLE_INVOICE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vehicle_invoice";

    static final String VEHICLE_CERTIFICATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vehicle_certificate";

    static final String INVOICE = "https://aip.baidubce.com/rest/2.0/ocr/v1/invoice";

    static final String AIR_TICKET = "https://aip.baidubce.com/rest/2.0/ocr/v1/air_ticket";

    static final String INSURANCE_DOCUMENTS = "https://aip.baidubce.com/rest/2.0/ocr/v1/insurance_documents";

    static final String VAT_INVOICE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vat_invoice";

    static final String QRCODE = "https://aip.baidubce.com/rest/2.0/ocr/v1/qrcode";

    static final String NUMBERS = "https://aip.baidubce.com/rest/2.0/ocr/v1/numbers";

    static final String LOTTERY = "https://aip.baidubce.com/rest/2.0/ocr/v1/lottery";

    static final String PASSPORT = "https://aip.baidubce.com/rest/2.0/ocr/v1/passport";

    static final String BUSINESS_CARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/business_card";

    static final String HANDWRITING = "https://aip.baidubce.com/rest/2.0/ocr/v1/handwriting";

    static final String CUSTOM = "https://aip.baidubce.com/rest/2.0/solution/v1/iocr/recognise";

    static final String DOC_ANALYSIS = "https://aip.baidubce.com/rest/2.0/ocr/v1/doc_analysis";

    static final String METER = "https://aip.baidubce.com/rest/2.0/ocr/v1/meter";

    static final String WEBIMAGE_LOC = "https://aip.baidubce.com/rest/2.0/ocr/v1/webimage_loc";

    static final int ASYNC_TASK_STATUS_FINISHED = 3;
}

==> java-sdk-4.16.3-sources.jar: com/baidu/aip/ocr/OcrConsts.java <==
/*
 * Copyright 2017 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidu.aip.ocr;

public class OcrConsts {

    static final String GENERAL_BASIC = "https://aip.baidubce.com/rest/2.0/ocr/v1/general_basic";

    static final String ACCURATE_BASIC = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate_basic";

    static final String GENERAL = "https://aip.baidubce.com/rest/2.0/ocr/v1/general";

    static final String ACCURATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate";

    static final String GENERAL_ENHANCED = "https://aip.baidubce.com/rest/2.0/ocr/v1/general_enhanced";

    static final String WEB_IMAGE = "https://aip.baidubce.com/rest/2.0/ocr/v1/webimage";

    static final String IDCARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/idcard";

    static final String BANKCARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/bankcard";

    static final String DRIVING_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/driving_license";

    static final String VEHICLE_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vehicle_license";

    static final String LICENSE_PLATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/license_plate";

    static final String BUSINESS_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/business_license";

    static final String RECEIPT = "https://aip.baidubce.com/rest/2.0/ocr/v1/receipt";

    static final String TRAIN_TICKET = "https://aip.baidubce.com/rest/2.0/ocr/v1/train_ticket";

    static final String TAXI_RECEIPT = "https://aip.baidubce.com/rest/2.0/ocr/v1/taxi_receipt";

    static final String FORM = "https://aip.baidubce.com/rest/2.0/ocr/v1/form";

    static final String TABLE_RECOGNIZE = "https://aip.baidubce.com/rest/2.0/solution/v1/form_ocr/request";

    static final String TABLE_RESULT_GET = "https://aip.baidubce.com/rest/2.0/solution/v1/form_ocr/get_request_result";

    static final String VIN_CODE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vin_code";

    static final String QUOTA_INVOICE = "https://aip.baidubce.com/rest/2.0/ocr/v1/quota_invoice";

    static final String HOUSEHOLD_REGISTER = "https://aip.baidubce.com/rest/2.0/ocr/v1/household_register";

    static final String HK_MACAU_EXITENTRYPERMIT = "https://aip.baidubce.com/rest/2.0/ocr/v1/HK_Macau_exitentrypermit";

    static final String TAIWAN_EXITENTRYPERMIT = "https://aip.baidubce.com/rest/2.0/ocr/v1/taiwan_exitentrypermit";

    static final String BIRTH_CERTIFICATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/birth_certificate";

    static final String VEHICLE_INVOICE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vehicle_invoice";

    static final String VEHICLE_CERTIFICATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vehicle_certificate";

    static final String INVOICE = "https://aip.baidubce.com/rest/2.0/ocr/v1/invoice";

    static final String AIR_TICKET = "https://aip.baidubce.com/rest/2.0/ocr/v1/air_ticket";

    static final String INSURANCE_DOCUMENTS = "https://aip.baidubce.com/rest/2.0/ocr/v1/insurance_documents";

    static final String VAT_INVOICE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vat_invoice";

    static final String QRCODE = "https://aip.baidubce.com/rest/2.0/ocr/v1/qrcode";

    static final String NUMBERS = "https://aip.baidubce.com/rest/2.0/ocr/v1/numbers";

    static final String LOTTERY = "https://aip.baidubce.com/rest/2.0/ocr/v1/lottery";

    static final String PASSPORT = "https://aip.baidubce.com/rest/2.0/ocr/v1/passport";

    static final String BUSINESS_CARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/business_card";

    static final String HANDWRITING = "https://aip.baidubce.com/rest/2.0/ocr/v1/handwriting";

    static final String CUSTOM = "https://aip.baidubce.com/rest/2.0/solution/v1/iocr/recognise";

    static final String DOC_ANALYSIS = "https://aip.baidubce.com/rest/2.0/ocr/v1/doc_analysis";

    static final String METER = "https://aip.baidubce.com/rest/2.0/ocr/v1/meter";

    static final String WEBIMAGE_LOC = "https://aip.baidubce.com/rest/2.0/ocr/v1/webimage_loc";

    static final int ASYNC_TASK_STATUS_FINISHED = 3;

    static final String  WEIGHT_NOTE = "https://aip.baidubce.com/rest/2.0/ocr/v1/weight_note";

    static final String  ONLINE_TAXI_ITINERARY = "https://aip.baidubce.com/rest/2.0/ocr/v1/online_taxi_itinerary";

    static final String  MEDICAL_DETAIL = "https://aip.baidubce.com/rest/2.0/ocr/v1/medical_detail";
}
